@@ -6,10 +6,11 @@ package Pod::Weaver::Section::Badges;
 
 # ABSTRACT: Add (or append) a section with badges
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Moose;
 use MooseX::AttributeDocumented;
+use PerlX::Maybe qw/provided/;
 use Types::Standard -types;
 use namespace::autoclean;
 use Pod::Weaver::Section::Badges::PluginSearcher;
@@ -131,7 +132,10 @@ sub weave_section {
 
     return if $self->main_module_only && $input->{'filename'} ne $self->main_module($input);
 
-    my $badge_objects = $self->create_badges;
+    my $badges_args = {
+        provided ref $input eq 'HASH' && exists $input->{'zilla'}, zilla => $input->{'zilla'},
+    };
+    my $badge_objects = $self->create_badges($badges_args);
     return if !scalar @$badge_objects;
 
     if(!$self->has_formats) {
@@ -180,9 +184,23 @@ __END__
 
 Pod::Weaver::Section::Badges - Add (or append) a section with badges
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Pod-Weaver-Section-Badges"><img src="https://api.travis-ci.org/Csson/p5-Pod-Weaver-Section-Badges.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Pod-Weaver-Section-Badges-0.0402"><img src="https://badgedepot.code301.com/badge/kwalitee/Pod-Weaver-Section-Badges/0.0402" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Pod-Weaver-Section-Badges%200.0402"><img src="https://badgedepot.code301.com/badge/cpantesters/Pod-Weaver-Section-Badges/0.0402" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-81.0%-orange.svg" alt="coverage 81.0%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.0401, released 2016-02-17.
+Version 0.0402, released 2016-02-20.
 
 
 
